import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { localized, msg } from "@lit/localize";
import { html } from "lit";
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { GdsElement } from "../../gds-element.js";
import { tokens } from "../../tokens.style.js";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { IconChevronLeft } from "../icon/icons/chevron-left.component.js";
import breadcrumbsCSS from "./breadcrumbs.styles.js";
let GdsBreadcrumbs = class extends withLayoutChildProps(
  withSizeXProps(withMarginProps(GdsElement))
) {
  constructor() {
    super(...arguments);
    this.size = "large";
    this.label = msg("Breadcrumbs");
  }
  render() {
    const elements = Array.from(this.children);
    const secondToLastIndex = elements.length - 2;
    return html`
      <nav
        role="navigation"
        aria-label=${this.label}
        class=${classMap({ "size-small": this.size === "small" })}
      >
        <div class="mobile-return">
          <gds-icon-chevron-left></gds-icon-chevron-left>
        </div>
        <ol>
          ${elements.map(
      (element, index) => html`
              <li
                class=${classMap({
        "show-on-mobile": index === secondToLastIndex
      })}
              >
                ${element}
              </li>
              ${index < elements.length - 1 ? html`<span class="separator" aria-hidden="true">/</span>` : null}
            `
    )}
        </ol>
      </nav>
    `;
  }
};
GdsBreadcrumbs.styles = [tokens, breadcrumbsCSS];
__decorateClass([
  property({ type: String })
], GdsBreadcrumbs.prototype, "size", 2);
__decorateClass([
  property({ type: String })
], GdsBreadcrumbs.prototype, "label", 2);
GdsBreadcrumbs = __decorateClass([
  gdsCustomElement("gds-breadcrumbs", {
    dependsOn: [IconChevronLeft]
  }),
  localized()
], GdsBreadcrumbs);
export {
  GdsBreadcrumbs
};
